changeset 13313:01303e66d1b2

Adapt to new char-table implementation. Fix name of file in the first line, part number syntax of ISO standards, and `provide' clause. Register file with RCS.
author Erik Naggum <erik@naggum.no>
date Sat, 28 Oct 1995 06:22:50 +0000
parents d408464ad235
children 661060193eb8
files lisp/international/latin-2.el
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/international/latin-2.el	Sat Oct 28 06:17:36 1995 +0000
+++ b/lisp/international/latin-2.el	Sat Oct 28 06:22:50 1995 +0000
@@ -1,4 +1,4 @@
 ;;; iso-syntax.el --- set up case-conversion and syntax tables for ISO 8859-2
 ;;;                   (ISO latin2, i.e. East Block character set)
 ;; Copyright (C) 1995 Free Software Foundation, Inc.
 
@@ -29,7 +29,7 @@
 
 (require 'case-table)
 
-(let ((downcase (concat (car (standard-case-table)))))
+(let ((downcase (standard-case-table)))
   (set-case-syntax 160 " " downcase)	  ; NBSP (no-break space)
   (set-case-syntax-pair 161 177 downcase) ; A with hook
   (set-case-syntax 162 "w" downcase)	  ; u accent
@@ -86,8 +86,8 @@
   (set-case-syntax 223 "w" downcase)	; small sharp s, German
   (set-case-syntax 247 "_" downcase)	; division sign
   (set-case-syntax 255 "w" downcase)	; dot accent
-  (set-standard-case-table (list downcase nil nil nil)))
+)
 
-(provide 'iso-syntax)
+(provide 'iso02-syn)
 
 ;;; iso-syntax.el ends here
@@ -1,4 +1,4 @@
-;;; iso-syntax.el --- set up case-conversion and syntax tables for ISO 8859-2
+;;; iso02-syn.el --- set up case-conversion and syntax tables for ISO 8859-2
 ;;;                   (ISO latin2, i.e. East Block character set)
 ;; Copyright (C) 1995 Free Software Foundation, Inc.